==> gitlab_17.3.5.orig.tar.bz2: gitlab-foss-v17.3.5/spec/frontend/organizations/shared/components/new_group_button_spec.js <==
import { GlButton } from '@gitlab/ui';
import { shallowMount } from '@vue/test-utils';
import NewGroupButton from '~/organizations/shared/components/new_group_button.vue';

describe('NewGroupButton', () => {
  let wrapper;

  const defaultProvide = {
    canCreateGroup: false,
    newGroupPath: '',
  };

  const defaultProps = {
    category: 'primary',
  };

  function createComponent({ provide = {}, props = {} } = {}) {
    wrapper = shallowMount(NewGroupButton, {
      provide: {
        ...defaultProvide,
        ...provide,
      },
      propsData: {
        ...defaultProps,
        ...props,
      },
    });
  }

  const findGlButton = () => wrapper.findComponent(GlButton);

  describe.each`
    canCreateGroup | newGroupPath
    ${false}       | ${null}
    ${false}       | ${'/asdf'}
    ${true}        | ${null}
  `(
    'when `canCreateGroup` is $canCreateGroup and `newGroupPath` is $newGroupPath',
    ({ canCreateGroup, newGroupPath }) => {
      beforeEach(() => {
        createComponent({ provide: { canCreateGroup, newGroupPath } });
      });

      it('renders nothing', () => {
        expect(wrapper.html()).toBe('');
      });
    },
  );

  describe('when `canCreateGroup` is true and `newGroupPath` is /asdf', () => {
    const newGroupPath = '/asdf';

    describe('with no category', () => {
      beforeEach(() => {
        createComponent({
          provide: { canCreateGroup: true, newGroupPath },
          props: { category: undefined },
        });
      });

      it('renders GlButton correctly', () => {
        expect(findGlButton().attributes('href')).toBe(newGroupPath);
        expect(findGlButton().props('category')).toBe(defaultProps.category);
      });
    });

    describe('with set category', () => {
      const category = 'secondary';

      beforeEach(() => {
        createComponent({ provide: { canCreateGroup: true, newGroupPath }, props: { category } });
      });

      it('renders GlButton correctly', () => {
        expect(findGlButton().attributes('href')).toBe(newGroupPath);
        expect(findGlButton().props('category')).toBe(category);
      });
    });
  });
});

==> gitlab_17.6.5.orig.tar.bz2: gitlab-foss-v17.6.5/spec/frontend/organizations/shared/components/new_group_button_spec.js <==
import { GlButton } from '@gitlab/ui';
import { shallowMount } from '@vue/test-utils';
import NewGroupButton from '~/organizations/shared/components/new_group_button.vue';

describe('NewGroupButton', () => {
  let wrapper;

  const defaultProvide = {
    canCreateGroup: false,
    newGroupPath: '',
  };

  const defaultProps = {
    category: 'primary',
  };

  function createComponent({ provide = {}, props = {} } = {}) {
    wrapper = shallowMount(NewGroupButton, {
      provide: {
        ...defaultProvide,
        ...provide,
      },
      propsData: {
        ...defaultProps,
        ...props,
      },
    });
  }

  const findGlButton = () => wrapper.findComponent(GlButton);

  describe.each`
    canCreateGroup | newGroupPath
    ${false}       | ${null}
    ${false}       | ${'/asdf'}
    ${true}        | ${null}
  `(
    'when `canCreateGroup` is $canCreateGroup and `newGroupPath` is $newGroupPath',
    ({ canCreateGroup, newGroupPath }) => {
      beforeEach(() => {
        createComponent({ provide: { canCreateGroup, newGroupPath } });
      });

      it('renders nothing', () => {
        expect(wrapper.find('*').exists()).toBe(false);
      });
    },
  );

  describe('when `canCreateGroup` is true and `newGroupPath` is /asdf', () => {
    const newGroupPath = '/asdf';

    describe('with no category', () => {
      beforeEach(() => {
        createComponent({
          provide: { canCreateGroup: true, newGroupPath },
          props: { category: undefined },
        });
      });

      it('renders GlButton correctly', () => {
        expect(findGlButton().attributes('href')).toBe(newGroupPath);
        expect(findGlButton().props('category')).toBe(defaultProps.category);
      });
    });

    describe('with set category', () => {
      const category = 'secondary';

      beforeEach(() => {
        createComponent({ provide: { canCreateGroup: true, newGroupPath }, props: { category } });
      });

      it('renders GlButton correctly', () => {
        expect(findGlButton().attributes('href')).toBe(newGroupPath);
        expect(findGlButton().props('category')).toBe(category);
      });
    });
  });
});
